pub struct LinksAttachmentData {
pub links: Vec<String>,
pub hash: String,
pub jws: Option<String>,
}Fields
links: Vec<String>A list of one or more locations at which the content may be fetched.
hash: StringThe hash of the content encoded in multi-hash format. Used as an integrity check for the attachment.
jws: Option<String>A JSON Web Signature over the content of the attachment.