Module payment

Module payment 

Payment types for TAP messages.

This module defines the structure of payment messages and related types used in the Transaction Authorization Protocol (TAP).

Structs

AssetPricing
Pricing object for supported assets (TAIP-14).
Payment
Payment message body (TAIP-14).
PaymentBuilder
Builder for Payment objects.

Enums

InvoiceReference
Invoice reference that can be either a URL or an Invoice object
SupportedAsset
A supported asset entry that can be either a simple asset identifier or a pricing object with amount and expiry (TAIP-14).