pub struct ConfirmRelationship {
pub transaction_id: String,
pub agent_id: String,
pub for_entity: String,
pub role: Option<String>,
}Expand description
ConfirmRelationship message body (TAIP-9).
This message type allows confirming a relationship between agents.
Fields
transaction_id: StringID of the transaction related to this message.
agent_id: StringDID of the agent whose relationship is being confirmed.
for_entity: StringThe entity this agent is acting for.
role: Option<String>The role of the agent (optional).
Implementations
Sourceimpl ConfirmRelationship
impl ConfirmRelationship
Sourcepub fn validate_relationship(&self) -> Result<()>
pub fn validate_relationship(&self) -> Result<()>
Custom validation for ConfirmRelationship messages