Module transfer

Module transfer 

Transfer message implementation for the Transaction Authorization Protocol.

This module defines the Transfer message type and its builder, which is the foundational message type for initiating a transfer in the TAP protocol.

Structs

TransactionValue
Fiat equivalent value for compliance purposes (TAIP-3).
Transfer
Transfer message body (TAIP-3).
TransferBuilder
Builder for creating Transfer objects in a more idiomatic way