Module settlement_address

Module settlement_address 

Settlement address types supporting both blockchain (CAIP-10) and traditional payment systems (RFC 8905).

This module provides types for handling settlement addresses that can be either blockchain addresses (CAIP-10 format) or traditional payment system identifiers (PayTo URI format per RFC 8905).

Structs

PayToUri
A PayTo URI per RFC 8905 for traditional payment systems.

Enums

SettlementAddress
A settlement address that can be either a blockchain address (CAIP-10) or a traditional payment system identifier (PayTo URI).
SettlementAddressError
Errors that can occur when parsing settlement addresses.