Agent management message types for the Transaction Authorization Protocol.
This module defines the message types for managing agents in the TAP protocol, including adding, replacing, and removing agents from transactions.
Structs
- AddAgents
- Add agents message body (TAIP-5).
- Remove
Agent - Remove agent message body (TAIP-5).
- Replace
Agent - Replace agent message body (TAIP-5).