pub trait Connectable {
// Required methods
fn with_connection(&mut self, connection_id: &str) -> &mut Self;
fn has_connection(&self) -> bool;
fn connection_id(&self) -> Option<&str>;
}Expand description
A trait for messages that can be connected to a prior Connect message.
This trait provides functionality for linking messages to a previous Connect message, enabling the building of message chains in the TAP protocol.
Required Methods
Sourcefn with_connection(&mut self, connection_id: &str) -> &mut Self
fn with_connection(&mut self, connection_id: &str) -> &mut Self
Sourcefn has_connection(&self) -> bool
fn has_connection(&self) -> bool
Check if this message is connected to a prior Connect message.
Returns
true if this message has a connection (pthid) set, false otherwise
Sourcefn connection_id(&self) -> Option<&str>
fn connection_id(&self) -> Option<&str>
Get the connection ID if present.
Returns
The Connect message ID this message is connected to, or None if not connected
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.