Utility functions for TAP core
This module provides utility functions used throughout the TAP core library.
Re-exports
pub use memo_hash::encode_binary_memo;pub use memo_hash::encode_text_memo;pub use memo_hash::tap_memo_hash;pub use memo_hash::verify_binary_memo;pub use memo_hash::verify_text_memo;pub use name_hash::hash_name;pub use name_hash::NameHashable;
Modules
- memo_
hash - TAIP-20 on-chain transfer correlation via memo hash.
- name_
hash - Name hashing utilities for TAIP-12 compliance
Functions
- get_
current_ time - Gets the current time as a unix timestamp (seconds since the epoch)